@@ -21,6 +21,10 @@ sub abstract {
     return 'Test distribution prerequisites against meta data.';
 }
 
+sub add_to_cleanup {
+    return [ qw{ cover_db xt/author/optionals } ];
+}
+
 sub author {
     return 'Thomas R. Wyant, III F<wyant at cpan dot org>';
 }
@@ -48,7 +52,7 @@ sub distribution {
 }
 
 sub license {
-    return 'perl_5';
+    return 'perl';
 }
 
 sub meta_merge {
@@ -127,6 +131,15 @@ sub requires_perl {
 }
 
 
+sub script_files {
+    return [
+    ];
+}
+
+sub version_from {
+    return 'lib/Test/Prereq/Meta.pm';
+}
+
 1;
 
 __END__
@@ -164,6 +177,11 @@ This method instantiates the class.
 
 This subroutine returns the distribution's abstract.
 
+=head2 add_to_cleanup
+
+This method returns a reference to an array of files to be added to the
+cleanup.
+
 =head2 author
 
 This subroutine returns the name of the distribution author
@@ -207,6 +225,18 @@ C<MAKING_MODULE_DISTRIBUTION> at the time the object was instantiated.
 
 This subroutine returns the distribution's license.
 
+=head2 meta_merge
+
+ use YAML;
+ print Dump( $meta->meta_merge() );
+
+This method returns a reference to a hash describing the meta-data which
+has to be provided by making use of the builder's C<meta_merge>
+functionality. This includes the C<dynamic_config> and C<resources>
+data.
+
+Any arguments will be appended to the generated array.
+
 =head2 module_name
 
 This subroutine returns the name of the module the distribution is based
@@ -246,6 +276,16 @@ may be added.
 
 This method returns the version of Perl required by the package.
 
+=head2 script_files
+
+This method returns a reference to an array containing the names of
+script files provided by this distribution. This array may be empty.
+
+=head2 version_from
+
+This method returns the name of the distribution file from which the
+distribution's version is to be derived.
+
 =head1 ATTRIBUTES
 
 This class has no public attributes.
