@@ -13,12 +13,12 @@ use File::Find ();
 use File::Glob ();
 use File::Spec;
 use Module::Extract::Use;
-use Module::CoreList 2.13;
+use Module::CoreList;
 use Module::Metadata;
 use Scalar::Util ();
 use Test::More 0.88;
 
-our $VERSION = '0.003_01';
+our $VERSION = '0.001';
 
 our @EXPORT_OK = qw{ all_prereq_ok file_prereq_ok prereq_ok };
 our %EXPORT_TAGS = (
@@ -69,8 +69,17 @@ sub new {
 	$code->( $name, \%arg );
     }
 
-    my $core_modules = _get_corelist_version( $arg{perl_version} )
-	or croak( "Unknown 'perl_version' $arg{perl_version}" );
+    my $core_modules;
+    {
+	# %Module::CoreList::version is public, so I figured the easiest
+	# implementation of the 'special' Perl versions was to just hack
+	# them into it.
+	local $Module::CoreList::version{none} = {};
+	local $Module::CoreList::version{this} =
+	    $Module::CoreList::version{$]};
+	$core_modules = $Module::CoreList::version{$arg{perl_version}}
+	    or croak( "Unknown 'perl_version' $arg{perl_version}" );
+    }
 
     # The below is pretty much verbatim from the CPAN::Meta synopsis
 
@@ -361,25 +370,6 @@ sub prereq_ok {
     return $self->all_prereq_ok();
 }
 
-sub _get_corelist_version {
-    my ( $perl_ver ) = @_;
-
-    $perl_ver eq 'none'
-	and return {};
-
-    $perl_ver eq 'this'
-	and $perl_ver = $];
-
-    my $data;
-    $data = $Module::CoreList::version{$perl_ver}
-	and return $data;
-
-    # The following is needed under very old versions of
-    # Module::CoreList -- pre-2.14 I think.
-    $perl_ver =~ s/ 0+ \z //smx;
-    return $Module::CoreList::version{$perl_ver};
-}
-
 sub _is_perl {
     my ( $file ) = @_;
     -T $file
@@ -467,11 +457,10 @@ sub __validate_meta_file {
     @{ $arg->{$name} }
 	or croak( "'$name' must specify at least one file" );
     foreach my $fn ( @{ $arg->{$name} } ) {
-	local $@ = undef;
-	eval {
-	    $arg->{"_$name"} = CPAN::Meta->load_file( $fn );
-	} or next;
+	-r $fn
+	    or next;
 	$arg->{$name} = $fn;
+	$arg->{"_$name"} = CPAN::Meta->load_file( $fn );
 	return;
     }
     1 == @{ $arg }
@@ -882,7 +871,6 @@ statements.
 =head1 SUPPORT
 
 Support is by the author. Please file bug reports at
-L<https://rt.cpan.org/Public/Dist/Display.html?Name=Test-Prereq-Meta>,
 L<https://github.com/trwyant/perl-Test-Prereq-Meta/issues>, or in
 electronic mail to the author.
 
@@ -892,7 +880,7 @@ Thomas R. Wyant, III F<wyant at cpan dot org>
 
 =head1 COPYRIGHT AND LICENSE
 
-Copyright (C) 2021-2022, 2025 by Thomas R. Wyant, III
+Copyright (C) 2021 by Thomas R. Wyant, III
 
 This program is free software; you can redistribute it and/or modify it
 under the same terms as Perl 5.10.0. For more details, see the full text
